@@ -10,13 +10,13 @@ use File::ShareDir qw( dist_file );
 use Path::Tiny 0.018 qw( cwd path );
 use Text::Template 1.48;
 use Text::Wrap    qw( wrap $columns );
-use Types::Common qw( InstanceOf Maybe NonEmptyStr NonEmptySimpleStr PositiveInt );
+use Types::Common qw( InstanceOf Maybe NonEmptyStr NonEmptySimpleStr PositiveOrZeroInt );
 
 use experimental qw( lexical_subs signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.4.1';
+our $VERSION = 'v0.5.0';
 
 
 has policy => (
@@ -80,7 +80,7 @@ has _template => (
 
 has text_columns => (
     is      => 'ro',
-    isa     => PositiveInt,
+    isa     => PositiveOrZeroInt,
     default => 78,
 );
 
@@ -106,6 +106,7 @@ has fulltext => (
 
         $columns = $self->text_columns;
         my sub _wrap($line) {
+            return $line unless $columns;
             return $line if $line =~ /^[ ]{4}/; # ignore preformatted code
             return wrap( "", $line =~ /^[\*\-](?![\*\-]) ?/ ? "  " : "", $line =~ s/[ ][ ]+/ /gr );
         }
@@ -149,7 +150,9 @@ Software::Policy::CodeOfConduct - generate a Code of Conduct policy
 
 =head1 VERSION
 
-version v0.4.1
+version v0.5.0
+
+=for stopwords fulltext
 
 =head1 SYNOPSIS
 
@@ -221,6 +224,8 @@ This should be a L<Text::Template> template file.
 
 This is the number of text columns for word-wrapping the L</text>.
 
+A value of C<0> disables word wrapping.
+
 The default is C<78>.
 
 =head2 filename
